@@ -1,7 +1,9 @@
-from marshmallow import fields
+from marshmallow import fields, EXCLUDE
 from cc_py_commons.schemas.camel_case_schema import CamelCaseSchema
 
 class EquipmentSchema(CamelCaseSchema):
+  class Meta:
+      unknown = EXCLUDE
   
   id = fields.UUID()
   name = fields.String()
\ No newline at end of file
